@@ -118,6 +118,9 @@ void ShibokenGenerator::initPrimitiveTypesCorrespondences()
     // Python operators
     m_pythonOperators.clear();
 
+    // call operator
+    m_pythonOperators["operator()"] = "call";
+
     // Arithmetic operators
     m_pythonOperators["operator+"] = "add";
     m_pythonOperators["operator-"] = "sub";
@@ -128,6 +131,8 @@ void ShibokenGenerator::initPrimitiveTypesCorrespondences()
     // Inplace arithmetic operators
     m_pythonOperators["operator+="] = "iadd";
     m_pythonOperators["operator-="] = "isub";
+    m_pythonOperators["operator++"] = "iadd";
+    m_pythonOperators["operator--"] = "isub";
     m_pythonOperators["operator*="] = "imul";
     m_pythonOperators["operator/="] = "idiv";
     m_pythonOperators["operator%="] = "imod";
@@ -387,7 +392,8 @@ QString ShibokenGenerator::guessScopeForDefaultValue(const AbstractMetaFunction*
 
     if (arg->type()->isEnum()) {
         const AbstractMetaEnum* metaEnum = findAbstractMetaEnum(arg->type());
-        prefix = resolveScopePrefix(metaEnum->enclosingClass(), value);
+        if (metaEnum)
+            prefix = resolveScopePrefix(metaEnum->enclosingClass(), value);
     } else if (arg->type()->isFlags()) {
         static QRegExp numberRegEx("^\\d+$"); // Numbers to flags
         if (numberRegEx.exactMatch(value)) {
@@ -1112,7 +1118,6 @@ void ShibokenGenerator::writeCodeSnips(QTextStream& s,
 
     // detect is we should use pyargs instead of args as variable name for python arguments
     bool usePyArgs = false;
-    int numArgs = 0;
     if (func) {
         // calc num of real arguments.
         int argsRemoved = 0;
@@ -1120,7 +1125,6 @@ void ShibokenGenerator::writeCodeSnips(QTextStream& s,
             if (func->argumentRemoved(i+1))
                 argsRemoved++;
         }
-        numArgs = func->arguments().size() - argsRemoved;
         usePyArgs = pythonFunctionWrapperUsesListOfArguments(OverloadData(getFunctionGroups(func->implementingClass())[func->name()], this));
     }
 
@@ -1221,6 +1225,15 @@ void ShibokenGenerator::writeCodeSnips(QTextStream& s,
                 code.replace("%CPPSELF.", replacement.arg(cppSelf));
                 code.replace("%CPPSELF", cppSelf);
 
+                if (code.indexOf("%BEGIN_ALLOW_THREADS") > -1) {
+                    if (code.count("%BEGIN_ALLOW_THREADS") == code.count("%END_ALLOW_THREADS")) {
+                        code.replace("%BEGIN_ALLOW_THREADS", BEGIN_ALLOW_THREADS);
+                        code.replace("%END_ALLOW_THREADS", END_ALLOW_THREADS);
+                    } else {
+                        ReportHandler::warning("%BEGIN_ALLOW_THREADS and %END_ALLOW_THREADS mismatch");
+                    }
+                }
+
                 // replace template variable for the Python Type object for the
                 // class implementing the method in which the code snip is written
                 if (func->isStatic()) {
@@ -1455,10 +1468,12 @@ AbstractMetaFunctionList ShibokenGenerator::getMethodsWithBothStaticAndNonStatic
 AbstractMetaClassList ShibokenGenerator::getBaseClasses(const AbstractMetaClass* metaClass) const
 {
     AbstractMetaClassList baseClasses;
-    foreach (QString parent, metaClass->baseClassNames()) {
-        AbstractMetaClass* clazz = classes().findClass(parent);
-        if (clazz)
-            baseClasses << clazz;
+    if (metaClass) {
+        foreach (QString parent, metaClass->baseClassNames()) {
+            AbstractMetaClass* clazz = classes().findClass(parent);
+            if (clazz)
+                baseClasses << clazz;
+        }
     }
     return baseClasses;
 }
@@ -1475,10 +1490,12 @@ const AbstractMetaClass* ShibokenGenerator::getMultipleInheritingClass(const Abs
 AbstractMetaClassList ShibokenGenerator::getAllAncestors(const AbstractMetaClass* metaClass) const
 {
     AbstractMetaClassList result;
-    AbstractMetaClassList baseClasses = getBaseClasses(metaClass);
-    foreach (AbstractMetaClass* base, baseClasses) {
-        result.append(base);
-        result.append(getAllAncestors(base));
+    if (metaClass) {
+        AbstractMetaClassList baseClasses = getBaseClasses(metaClass);
+        foreach (AbstractMetaClass* base, baseClasses) {
+            result.append(base);
+            result.append(getAllAncestors(base));
+        }
     }
     return result;
 }
