@@ -15,6 +15,7 @@
 #include "list.h"
 #include "listuser.h"
 #include "mapuser.h"
+#include "modelindex.h"
 #include "modifications.h"
 #include "modified_constructor.h"
 #include "multiple_derived.h"
@@ -37,6 +38,7 @@
 #include "privatector.h"
 #include "privatedtor.h"
 #include "protected.h"
+#include "rect.h"
 #include "reference.h"
 #include "removednamespaces.h"
 #include "samplenamespace.h"
